==> gidapptools-0.2.4-py3-none-any.whl: gidapptools/gidapptools_qt/basics/main_window.py <==
"""
WiP.

Soon.
"""

# region [Imports]

import os
import re
import sys
import json
import queue
import math
import base64
import pickle
import random
import shelve
import dataclasses
import shutil
import asyncio
import logging
import sqlite3
import platform
import importlib
import subprocess
import inspect

from time import sleep, process_time, process_time_ns, perf_counter, perf_counter_ns
from io import BytesIO, StringIO
from abc import ABC, ABCMeta, abstractmethod
from copy import copy, deepcopy
from enum import Enum, Flag, auto, unique
from time import time, sleep
from pprint import pprint, pformat
from pathlib import Path
from string import Formatter, digits, printable, whitespace, punctuation, ascii_letters, ascii_lowercase, ascii_uppercase
from timeit import Timer
from typing import TYPE_CHECKING, Union, Callable, Iterable, Optional, Mapping, Any, IO, TextIO, BinaryIO, Hashable, Generator, Literal, TypeVar, TypedDict, AnyStr
from zipfile import ZipFile, ZIP_LZMA
from datetime import datetime, timezone, timedelta
from tempfile import TemporaryDirectory
from textwrap import TextWrapper, fill, wrap, dedent, indent, shorten
from functools import wraps, partial, lru_cache, singledispatch, total_ordering, cached_property
from importlib import import_module, invalidate_caches
from contextlib import contextmanager, asynccontextmanager, nullcontext, closing, ExitStack, suppress
from statistics import mean, mode, stdev, median, variance, pvariance, harmonic_mean, median_grouped
from collections import Counter, ChainMap, deque, namedtuple, defaultdict
from urllib.parse import urlparse
from importlib.util import find_spec, module_from_spec, spec_from_file_location
from concurrent.futures import ThreadPoolExecutor, ProcessPoolExecutor
from importlib.machinery import SourceFileLoader


import PySide6
from PySide6 import (QtCore, QtGui, QtWidgets, Qt3DAnimation, Qt3DCore, Qt3DExtras, Qt3DInput, Qt3DLogic, Qt3DRender, QtAxContainer, QtBluetooth,
                     QtCharts, QtConcurrent, QtDataVisualization, QtDesigner, QtHelp, QtMultimedia, QtMultimediaWidgets, QtNetwork, QtNetworkAuth,
                     QtOpenGL, QtOpenGLWidgets, QtPositioning, QtPrintSupport, QtQml, QtQuick, QtQuickControls2, QtQuickWidgets, QtRemoteObjects,
                     QtScxml, QtSensors, QtSerialPort, QtSql, QtStateMachine, QtSvg, QtSvgWidgets, QtTest, QtUiTools, QtWebChannel, QtWebEngineCore,
                     QtWebEngineQuick, QtWebEngineWidgets, QtWebSockets, QtXml)

from PySide6.QtCore import (QByteArray, QCoreApplication, QDate, QDateTime, QEvent, QLocale, QMetaObject, QModelIndex, QModelRoleData, QMutex,
                            QMutexLocker, QObject, QPoint, QRect, QRecursiveMutex, QRunnable, QSettings, QSize, QThread, QThreadPool, QTime, QUrl,
                            QWaitCondition, Qt, QAbstractItemModel, QAbstractListModel, QAbstractTableModel, Signal, Slot)

from PySide6.QtGui import (QAction, QBrush, QColor, QConicalGradient, QCursor, QFont, QFontDatabase, QFontMetrics, QGradient, QIcon, QImage,
                           QKeySequence, QLinearGradient, QPainter, QPalette, QPixmap, QRadialGradient, QTransform)

from PySide6.QtWidgets import (QApplication, QBoxLayout, QCheckBox, QColorDialog, QColumnView, QComboBox, QDateTimeEdit, QDialogButtonBox,
                               QDockWidget, QDoubleSpinBox, QFontComboBox, QFormLayout, QFrame, QGridLayout, QGroupBox, QHBoxLayout, QHeaderView,
                               QLCDNumber, QLabel, QLayout, QLineEdit, QListView, QListWidget, QMainWindow, QMenu, QMenuBar, QMessageBox,
                               QProgressBar, QProgressDialog, QPushButton, QSizePolicy, QSpacerItem, QSpinBox, QStackedLayout, QStackedWidget,
                               QStatusBar, QStyledItemDelegate, QSystemTrayIcon, QTabWidget, QTableView, QTextEdit, QTimeEdit, QToolBox, QTreeView,
                               QVBoxLayout, QWidget, QAbstractItemDelegate, QAbstractItemView, QAbstractScrollArea, QRadioButton, QFileDialog, QButtonGroup)
from gidapptools.errors import ApplicationNotExistingError
from gidapptools.gidapptools_qt.basics.menu_bar import BaseMenuBar
from gidapptools.gidapptools_qt.basics.status_bar import GidBaseStatusBar
import pp
if TYPE_CHECKING:
    from gidapptools.gidapptools_qt.basics.application import GidQtApplication
# endregion[Imports]

# region [TODO]


# endregion [TODO]

# region [Logging]


# endregion[Logging]

# region [Constants]

THIS_FILE_DIR = Path(__file__).parent.absolute()

# endregion[Constants]


class GidBaseMainWindow(QMainWindow):

    def __init__(self, parent: Optional[PySide6.QtWidgets.QWidget] = None, flags: PySide6.QtCore.Qt.WindowFlags = None, menu_bar: BaseMenuBar = None, status_bar: GidBaseStatusBar = None) -> None:
        super().__init__(*(i for i in [parent, flags] if i))
        self.setObjectName("MainWindow")
        self.menu_bar = menu_bar or BaseMenuBar(auto_connect_standard_actions=True)
        self.status_bar = status_bar or GidBaseStatusBar()

    @property
    def app(self) -> "GidQtApplication":
        app = QApplication.instance()
        if app is None:
            raise ApplicationNotExistingError()
        return app

    @property
    def central_widget(self) -> QWidget:
        return super().centralWidget()

    @central_widget.setter
    def central_widget(self, widget: QWidget):
        self.setCentralWidget(widget)

    @property
    def menu_bar(self) -> BaseMenuBar:
        return super().menuBar()

    @menu_bar.setter
    def menu_bar(self, menu_bar: BaseMenuBar):
        menu_bar.setParent(self)
        try:
            menu_bar.setup()
        except AttributeError:
            pass
        self.setMenuBar(menu_bar)

    @property
    def status_bar(self) -> QStatusBar:
        return super().statusBar()

    @status_bar.setter
    def status_bar(self, status_bar: QStatusBar):
        status_bar.setParent(self)
        try:
            status_bar.setup()
        except AttributeError:
            pass
        self.setStatusBar(status_bar)
# region[Main_Exec]


if __name__ == '__main__':
    pass

# endregion[Main_Exec]

==> gidapptools-0.4.3-py3-none-any.whl: gidapptools/gidapptools_qt/basics/main_window.py <==
"""
WiP.

Soon.
"""

# region [Imports]

# * Standard Library Imports ---------------------------------------------------------------------------->
from typing import TYPE_CHECKING, Optional
from pathlib import Path

# * Qt Imports --------------------------------------------------------------------------------------->
import PySide6
from PySide6.QtWidgets import QWidget, QStatusBar, QMainWindow, QApplication

# * Gid Imports ----------------------------------------------------------------------------------------->
from gidapptools.errors import ApplicationNotExistingError
from gidapptools.gidapptools_qt.basics.menu_bar import BaseMenuBar
from gidapptools.gidapptools_qt.basics.status_bar import GidBaseStatusBar

# * Type-Checking Imports --------------------------------------------------------------------------------->
if TYPE_CHECKING:
    from gidapptools.gidapptools_qt.basics.application import GidQtApplication

# endregion[Imports]

# region [TODO]


# endregion [TODO]

# region [Logging]


# endregion[Logging]

# region [Constants]

THIS_FILE_DIR = Path(__file__).parent.absolute()

# endregion[Constants]


class GidBaseMainWindow(QMainWindow):

    def __init__(self, parent: Optional[PySide6.QtWidgets.QWidget] = None, flags: PySide6.QtCore.Qt.WindowFlags = None, menu_bar: BaseMenuBar = None, status_bar: GidBaseStatusBar = None) -> None:
        super().__init__(*(i for i in [parent, flags] if i))
        self.setObjectName("MainWindow")
        self.menu_bar = menu_bar or BaseMenuBar(auto_connect_standard_actions=True)
        self.status_bar = status_bar or GidBaseStatusBar()

    @property
    def app(self) -> "GidQtApplication":
        app = QApplication.instance()
        if app is None:
            raise ApplicationNotExistingError()
        return app

    @property
    def central_widget(self) -> QWidget:
        return super().centralWidget()

    @central_widget.setter
    def central_widget(self, widget: QWidget):
        self.setCentralWidget(widget)

    @property
    def menu_bar(self) -> BaseMenuBar:
        return super().menuBar()

    @menu_bar.setter
    def menu_bar(self, menu_bar: BaseMenuBar):
        menu_bar.setParent(self)
        try:
            menu_bar.setup()
        except AttributeError:
            pass
        self.setMenuBar(menu_bar)

    @property
    def status_bar(self) -> QStatusBar:
        return super().statusBar()

    @status_bar.setter
    def status_bar(self, status_bar: QStatusBar):
        status_bar.setParent(self)
        try:
            status_bar.setup()
        except AttributeError:
            pass
        self.setStatusBar(status_bar)
# region[Main_Exec]


if __name__ == '__main__':
    pass

# endregion[Main_Exec]
